#ifndef MAINWINDOW_H 
#define MAINWINDOW_H

#include <QAction>
#include <QCursor>
#include <QMainWindow>
#include <QProcess>
#include <QToolBar>
#include <QTabWidget>
//Added by qt3to4:
#include <QCloseEvent>
#include <QShowEvent>
#include <QHideEvent>

#include "file.h"
#include "findwindow.h"
#include "mapeditor.h"
#include "texteditor.h"
#include "xml.h"

class Main : public QMainWindow 
{
    Q_OBJECT

public:
    Main(QWidget* parent=0, const char* name=0, Qt::WFlags f=0);
    ~Main();
	void loadCmdLine();
	void statusMessage (const QString &);

public slots:
    void fileNew();

protected:
	void closeEvent( QCloseEvent* );

private:
    void setupFileActions();
    void setupEditActions();
    void setupFormatActions();
    void setupViewActions();
    void setupModeActions();
    void setupWindowActions();
    void setupFlagActions();
    void setupSettingsActions();
    void setupTestActions();
    void setupHelpActions();
    void setupContextMenus();
	void setupLastMapsMenu();
	void hideEvent (QHideEvent * );
	void showEvent (QShowEvent * );
	bool reallyWriteDirectory(const QString&);
	QString browseDirectory(const QString&);
	MapEditor* currentMapEditor() const;
    
private slots:
    void newView();
	void editorChanged(QWidget*);

    ErrorCode fileLoad(QString ,const LoadMode &);
    void fileLoad(const LoadMode &);
    void fileLoad();
	void fileLoadLast(QAction *);
    void fileSave(const SaveMode & );
    void fileSave();
    void fileSaveAs(const SaveMode &);
    void fileSaveAs();
    void fileImportKDEBookmarks();
    void fileImportFirefoxBookmarks();
    void fileImportMM();
    void fileImportDir();
    void fileExportXML();
    void fileExportXHTML();
    void fileExportImage();
    void fileExportASCII();
    void fileExportLaTeX();
    void fileExportKDEBookmarks();
    void fileExportTaskjuggler();
    void fileExportOOPresentation();
    void fileCloseMap();
    void filePrint();
    void fileExitVYM();

    void editUndo();	
    void editRedo();	
    void editCopy();	
    void editPaste();	
    void editCut();	
    void editOpenFindWindow();
	void editFind(QString);
	void editFindChanged();
private:
	void openTabs(QStringList);
public slots:
	void editOpenURL();
	void editOpenURLTab();
private slots:
	void editOpenMultipleURLTabs();
	void editURL();
	void editHeading2URL();
	void editBugzilla2URL();
	void editFATE2URL();
	void openVymLinks(const QStringList &);
	void editVymLink();
	void editOpenMultipleVymLinks();
public slots:
    void editHeading();
	void editOpenVymLink();
private slots:
	void editDeleteVymLink();
	void editToggleHideExport();
	void editMapInfo();
    void editMoveUp();	
    void editMoveDown();	
    void editToggleScroll();
    void editUnScrollAll();
    void editNewBranch();
    void editNewBranchHere();
    void editNewBranchAbove();
    void editNewBranchBelow();
    void editImportAdd();
    void editImportReplace();
    void editSaveBranch();
    void editRemoveBranchKeepChilds();
    void editRemoveChilds();
    void editDeleteSelection();
    void editUpperBranch();
    void editLowerBranch();
    void editLeftBranch();
    void editRightBranch();
    void editFirstBranch();
    void editLastBranch();
    void editLoadImage();
    void editSaveImage();
    void editFollowXLink (QAction *);
    void editEditXLink (QAction *);

    void formatSelectColor();
    void formatPickColor();
    void colorChanged(QColor);
    void formatColorItem();
    void formatColorBranch();
	void formatLinkStyleLine();
	void formatLinkStyleParabel();
	void formatLinkStylePolyLine();
	void formatLinkStylePolyParabel();
    void formatSelectBackColor();
    void formatSelectLinkColor();
    void formatToggleLinkColorHint();
	void formatFrameNone();
	void formatFrameRectangle();
	void formatIncludeImagesVer();
	void formatIncludeImagesHor();
	void formatHideLinkUnselected();

    void viewZoomReset();
    void viewZoomIn();
    void viewZoomOut();

	void modModeColor();
	void modModeLink();

public slots:
	bool settingsPDF();
	bool settingsURL();
	void settingsToggleDelKey();

	void windowToggleNoteEditor();
	void windowToggleHistory();
	void updateNoteFlag();

private slots:
	void windowNextEditor();
	void windowPreviousEditor();
	void windowShowNoteEditor();
	void windowHideNoteEditor();

	void standardFlagChanged();

    void testFunction();

    void helpDoc();
    void helpAbout();
    void helpAboutQT();

private:
	QTabWidget *tabWidget;
	FindWindow *findWindow;
	QStringList lastMaps;
	int maxLastMaps;
	QProcess *procBrowser;

	QStringList imageTypes;

	QLineEdit *lineedit;	// to enter headings of branches
	QString editSel;
	
};


#endif

